@@ -13,7 +13,7 @@ gi.require_version('Gtk', '3.0')
 
 from gi.repository import Gio, GLib, Gtk, Gdk, GdkPixbuf  # noqa: E402
 
-version = '0.0.8'
+version = '0.0.9'
 
 
 @contextlib.contextmanager
@@ -35,12 +35,18 @@ def _mpd_client(*args, **kwargs):
         client.disconnect()
 
 
-def app_main(mpd_host, mpd_port):
-    win = Gtk.Window(default_height=500, default_width=500)
-    win.connect('destroy', Gtk.main_quit)
+def app_main(mpd_host, mpd_port, background_color):
+    css_provider = Gtk.CssProvider()
+    css_provider.load_from_data(
+        f'* {{ background-color: {background_color}; }}'.encode())
+    context = Gtk.StyleContext()
+    screen = Gdk.Screen.get_default()
 
-    win.override_background_color(
-        Gtk.StateType.NORMAL, Gdk.RGBA(red=0, green=0, blue=0))
+    context.add_provider_for_screen(screen, css_provider,
+                                    Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION)
+    win = Gtk.Window(default_height=500, default_width=500)
+
+    win.connect('destroy', Gtk.main_quit)
 
     image = Gtk.Image()
     pixbuf = None
@@ -124,6 +130,9 @@ def main():
     parser.add_argument(
         '--port', type=int, default=6600,
         help='MPD port (default: %(default)s)')
+    parser.add_argument('--background-color', default='#000000',
+                        metavar='COLOR',
+                        help='background-color (default: %(default)s)')
     parser.add_argument('--version', action='version', version=version)
     args = parser.parse_args()
 
@@ -137,7 +146,7 @@ def main():
     if mpd_host is None:
         mpd_host = 'localhost'
 
-    app_main(mpd_host, args.port)
+    app_main(mpd_host, args.port, args.background_color)
     Gtk.main()
 
 
